==> dde-device-formatter_1.5.4.tar.xz: BUILD/translations/dde-device-formatter_ne.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ne" version="2.1">
<context>
    <name>FinishPage</name>
    <message>
        <location filename="../view/finishpage.cpp" line="42"/>
        <source>Format successful</source>
        <translation>फर्म्याट सफलभयो </translation>
    </message>
</context>
<context>
    <name>FormatingPage</name>
    <message>
        <location filename="../view/formatingpage.cpp" line="47"/>
        <source>Formatting the disk, please wait...</source>
        <translation>डिस्क फर्म्याट गर्दै, कृपया प्रतीक्षा गर्नुहोस् ...</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../view/mainpage.cpp" line="119"/>
        <source>Type</source>
        <translation>प्रकार</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="137"/>
        <source>Label</source>
        <translation>लेबल</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="146"/>
        <source>Quick Format</source>
        <translation>द्रुत गतिमा  फर्म्याट </translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="163"/>
        <source>Formatting will erase all data on the disk.</source>
        <translation>फर्म्याटिले डिस्कमा भाएको सबै डाटा मेटिनेछ।</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../view/mainwindow.cpp" line="88"/>
        <location filename="../view/mainwindow.cpp" line="106"/>
        <source>Format</source>
        <translation>फर्म्याट </translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="162"/>
        <source>Continue</source>
        <translation>जारी राख्नुहोस्</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="167"/>
        <source>Formatting...</source>
        <translation>फर्म्याट गर्दै</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="193"/>
        <source>Done</source>
        <translation>भयो</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="199"/>
        <source>Quit</source>
        <translation>छोड्नुहोस्</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="200"/>
        <source>Your disk has been removed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your disk is removed when formatting</source>
        <translation type="vanished">फर्म्याट गर्दा तपाईंको डिस्क हटाइन्छ</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="203"/>
        <source>Failed to format the device</source>
        <translation>उपकरण फर्म्याट गर्न असफल भयो
 </translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="204"/>
        <source>Reformat</source>
        <translation>पुन: फर्म्याट </translation>
    </message>
</context>
<context>
    <name>MessageDialog</name>
    <message>
        <location filename="../dialogs/messagedialog.cpp" line="43"/>
        <source>OK</source>
        <translation>ठिक छ</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../utils/udisksutils.cpp" line="55"/>
        <source>System Disk</source>
        <translation>प्रणाली डिस्क</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="59"/>
        <source>%1 Encrypted</source>
        <translation>% 1 ईन्क्रिप्टेड</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="61"/>
        <source>%1 Volume</source>
        <translation>% 1 खण्ड</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="90"/>
        <source>Device does not exist</source>
        <translation>उपकरण अवस्थित छैन</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>The device is read-only</source>
        <translation>उपकरण पढ्ने मात्र हो</translation>
    </message>
    <message>
        <source>Cannot format local device</source>
        <translation type="vanished">स्थानीय उपकरण फर्म्याट गर्न सकिदैन</translation>
    </message>
</context>
<context>
    <name>WarnPage</name>
    <message>
        <location filename="../view/warnpage.cpp" line="43"/>
        <source>Formatting will erase all data on this disk, are you sure you want to continue? It cannot be restored.</source>
        <translation>फर्म्याटिले यस डिस्कमा सबै डाटा मेटिनेछ, के तपाइँ पक्का हुनुहुन्छ तपाइँ जारी राख्न चाहानुहुन्छ? यो पूर्वावस्थामा ल्याउन सकिदैन।</translation>
    </message>
</context>
</TS>

==> dde-device-formatter_1.5.5.tar.xz: BUILD/translations/dde-device-formatter_ne.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ne">
<context>
    <name>FinishPage</name>
    <message>
        <location filename="../view/finishpage.cpp" line="22"/>
        <source>Format successful</source>
        <translation>फर्म्याट सफलभयो </translation>
    </message>
</context>
<context>
    <name>FormatingPage</name>
    <message>
        <location filename="../view/formatingpage.cpp" line="29"/>
        <source>Formatting the disk, please wait...</source>
        <translation>डिस्क फर्म्याट गर्दै, कृपया प्रतीक्षा गर्नुहोस् ...</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../view/mainpage.cpp" line="99"/>
        <source>Type</source>
        <translation>प्रकार</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="117"/>
        <source>Label</source>
        <translation>लेबल</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="127"/>
        <source>Quick Format</source>
        <translation>द्रुत गतिमा  फर्म्याट </translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="144"/>
        <source>Formatting will erase all data on the disk.</source>
        <translation>फर्म्याटिले डिस्कमा भाएको सबै डाटा मेटिनेछ।</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../view/mainwindow.cpp" line="68"/>
        <source>Format</source>
        <translation>फर्म्याट </translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="250"/>
        <source>Continue</source>
        <translation>जारी राख्नुहोस्</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="256"/>
        <source>Formatting...</source>
        <translation>फर्म्याट गर्दै</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="290"/>
        <source>Done</source>
        <translation>भयो</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="303"/>
        <source>Quit</source>
        <translation>छोड्नुहोस्</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="304"/>
        <source>Your disk has been removed</source>
        <translation>तपाईँको डिस्क हटाइएको छ</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="308"/>
        <source>Failed to format the device</source>
        <translation>उपकरण फर्म्याट गर्न असफल भयो
 </translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="309"/>
        <source>Reformat</source>
        <translation>पुन: फर्म्याट </translation>
    </message>
</context>
<context>
    <name>MessageDialog</name>
    <message>
        <location filename="../dialogs/messagedialog.cpp" line="23"/>
        <source>OK</source>
        <translation>ठिक छ</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../utils/udisksutils.cpp" line="40"/>
        <source>System Disk</source>
        <translation>प्रणाली डिस्क</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="46"/>
        <source>%1 Encrypted</source>
        <translation>% 1 ईन्क्रिप्टेड</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="50"/>
        <source>%1 Volume</source>
        <translation>% 1 खण्ड</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>dde device formatter</source>
        <translation>dde डिवाइस फॉर्मेटर</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="97"/>
        <source>Device does not exist</source>
        <translation>उपकरण अवस्थित छैन</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="107"/>
        <source>The device is read-only</source>
        <translation>उपकरण पढ्ने मात्र हो</translation>
    </message>
</context>
<context>
    <name>WarnPage</name>
    <message>
        <location filename="../view/warnpage.cpp" line="23"/>
        <source>Formatting will erase all data on this disk, are you sure you want to continue? It cannot be restored.</source>
        <translation>फर्म्याटिले यस डिस्कमा सबै डाटा मेटिनेछ, के तपाइँ पक्का हुनुहुन्छ तपाइँ जारी राख्न चाहानुहुन्छ? यो पूर्वावस्थामा ल्याउन सकिदैन।</translation>
    </message>
</context>
</TS>
